@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -106,7 +105,6 @@ module SiSU_DAL
       @idx_xhtml=@make_fns.marshal.dal_idx_xhtml
       @map_nametags=@make_fns.marshal.dal_map_nametags
       @map_ocn_htmlseg=@make_fns.marshal.dal_map_ocn_htmlseg
-      SiSU_Env::CreateSystemLink.new.images
       @env=SiSU_Env::InfoEnv.new
     end
     def read                                                                   #creates dal
@@ -272,6 +270,9 @@ module SiSU_DAL
       fn=(@fnx && @fnx =~/\.ss[tmi]$/) \
       ? @fnx
       : @opt.fns
+      if @opt.fno =~/\.txz$/
+        Dir.chdir(@opt.f_pth[:pth])
+      end
       file_array=@env.read_source_file(fn)
       file_array.each do |l|
         if l =~/\r\n/; l.gsub!(/\r\n/,"\n")
