@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -73,7 +72,7 @@ module SiSU_Manifest
     def initialize(opt)
       @opt=opt
       @particulars=SiSU_Particulars::CombinedSingleton.instance.get_all(opt)
-      l=SiSU_Env::StandardiseLanguage.new(@opt.lng).language
+      l=SiSU_Env::StandardiseLanguage.new(opt.lng).language
       @doc_language=l[:n]
     end
     def read
@@ -98,6 +97,7 @@ module SiSU_Manifest
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
+        SiSU_Env::CreateSite.new(@opt.cmd).cp_css
       end
     end
     private
@@ -105,12 +105,11 @@ module SiSU_Manifest
       def initialize(md)
         @manifest={ txt: [], html: [] }
         @md,@fns=md,md.fns
-        @env=SiSU_Env::InfoEnv.new(@md.fns)
-        @make=SiSU_Env::ProcessingSettings.new(@md)
-        @fnb=@md.fnb
+        @env=SiSU_Env::InfoEnv.new(md.fns)
+        @f=SiSU_Env::FileOp.new(md)
+        @fnb=md.fnb
         @base_url="#{@env.url.root}/#{@fnb}"
-        @f=SiSU_Env::FileOp.new(@md)
-        @o_str=SiSU_Env::ProcessingSettings.new(md).output_dir_structure
+        @o_str=SiSU_Env::FileOp.new(md).output_dir_structure
         @image_path=if @o_str.dump_or_redirect?
           %{./image}
         else
@@ -119,9 +118,9 @@ module SiSU_Manifest
         @base_path=@f.output_path.manifest.dir
         @@dg ||=SiSU_Env::InfoEnv.new.digest.type
         @dg=@@dg
-        l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
+        l=SiSU_Env::StandardiseLanguage.new(md.opt.lng).language
         @language=l[:n]
-        @translate=SiSU_Translate::Source.new(@md,@language)
+        @translate=SiSU_Translate::Source.new(md,@language)
         @brace_url=SiSU_Viz::Skin.new.url_decoration
         @stylesheet=SiSU_Style::CSS_HeadInfo.new(md).stylesheet
       end
@@ -179,13 +178,13 @@ module SiSU_Manifest
             mt="#{mp}/#{mn}"
             mr="../../#{lc}/manifest/#{mn}"
             mu="#{url}/#{mn}"
-          elsif @env.output_dir_structure.by_language_code?
+          elsif @f.output_dir_structure.by_language_code?
             mp="#{@f.output_path.base.dir}/#{lc}/manifest"
             mn="#{@md.fnb}.html"
             mt="#{mp}/#{mn}"
             mr="../../#{lc}/manifest/#{mn}"
             mu="#{url}/#{lc}/manifest/#{mn}"
-          elsif @env.output_dir_structure.by_filetype?
+          elsif @f.output_dir_structure.by_filetype?
             mp="#{@f.output_path.base.dir}/manifest"
             mn="#{@md.fnb}.#{lc}.html"
             mt="#{mp}/#{mn}"
@@ -497,7 +496,7 @@ WOK
         end
         if FileTest.file?(@f.place_file.sisupod.dir)==true
           pth=@f.output_path.sisupod.dir
-          rel=@f.output_path.sisupod.rel_sm
+          rel=@f.output_path.sisupod.ab_pod
           url=@f.output_path.sisupod.url
           id,file='SiSU doc (tar.xz)',@f.base_filename.sisupod
           summarize_sources(id,file,pth,rel,url)
@@ -769,7 +768,7 @@ WOK
           minitoc=SiSU_HTML_MiniToc::TocMini.new(@md,data).songsheet.join("\n")
           id,file='',''
           vz=SiSU_Env::GetInit.instance.skin
-          search_form=if @make.build.search_form?
+          search_form=if @f.build.search_form?
             "<td>#{@env.widget_static.search_form}</td>"
           else ''
           end
@@ -808,10 +807,10 @@ SiSU manifest: #{@md.title.full}
 <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
 #{banner_table}
 WOK
-          if @make.build.manifest_minitoc?
+          if @f.build.manifest_minitoc?
             if @o_str.dump_or_redirect?
-            elsif @env.output_dir_structure.by_language_code? \
-            or @env.output_dir_structure.by_filetype?
+            elsif @f.output_dir_structure.by_language_code? \
+            or @f.output_dir_structure.by_filetype?
               minitoc=minitoc.gsub(/<a href="(\S+?)"/m,%{<a href="../html/#{@md.fnb}/\\1"}).
                 gsub(/<a href="\.\.\/html\/#{@md.fnb}\/(?:sisu_manifest\.html|#{@f.base_filename.manifest})"/m,
               %{<a href="#{@f.base_filename.manifest}"})
@@ -838,7 +837,7 @@ WOK
 &nbsp;&nbsp;<a href="#metadata">Document Metadata</a>
 </p>
 <p class="tiny">
-&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="#links">(metadata suggested links (if any)</a>
+&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="#links">metadata suggested links (if any)</a>
 </p>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 WOK
