@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -144,14 +143,14 @@ module SiSU_Doc
       sk_doc,sk_dir="doc/#{skin}.rb","dir/skin_#{@env.stub_pwd}.rb"
       skin_path.each do |v|                                                    #document skin priority 1
         if FileTest.file?("#{v}/#{sk_doc}")
-          @skin[:name],@skin[:type]="#{v}/#{sk_doc}",'doc'
+          @skin={ name_path: "#{v}/#{sk_doc}", type: :doc }
           break
         end
       end
       unless @skin.length > 0
         skin_path.each do |v|                                                  #directory skin priority 2
           if FileTest.file?("#{v}/#{sk_dir}")
-            @skin[:name],@skin[:type]="#{v}/#{sk_dir}",'dir'
+            @skin={ name_path: "#{v}/#{sk_dir}", type: :dir }
             break
           end
         end
@@ -168,7 +167,7 @@ module SiSU_Doc
     end
     def sisupod_build                                                          #see also sisupod in sysenv
       @pwd=Dir.pwd
-      @rgx_rb_image=/["'](\S+?\.(?:png|jpg|gif))["']/
+      @rgx_rb_image=/["']\S*?([a-zA-Z0-9_-]+?\.(?:png|jpg|gif))["']/
       @rgx_image=/(?:^|[^_\\])\{\s*(\S+?\.(?:png|jpg|gif))/
       @rgx_skin=/^\s+:skin:\s+(\S+)/
       @rgx_doc_import=/^<<\s*(\S+?\.ss[ti])/
@@ -208,25 +207,28 @@ module SiSU_Doc
       else
         skin_source=select_skin
       end
-      docskin_place="#{@env.processing_path.processing_sisupod(@opt)}/doc/_sisu/skin/#{skin_source[:type]}"
+      docskin_place="#{@env.processing_path.processing_sisupod(@opt)}/doc/_sisu/skin/#{skin_source[:type].to_s}"
       FileUtils::mkdir_p(docskin_place)
-      if skin_source[:type] =~/dir/
+      if skin_source[:type] == :dir
         docskin_with_path="#{docskin_place}/skin_#{@env.stub_pwd}.rb"
         docskin=[docskin_with_path.gsub(/.+?\/(skin_\S+?)\.rb/,'\1')]
         docskin='skin_sisupod'
       end
       if skin_source \
-      and docskin #imperfect, revisit
-        unless skin_source[:name].nil? \
-        or skin_source[:name].empty?
-          FileUtils::cp_r(skin_source[:name],"#{docskin_place}/#{docskin}.rb")
-          skinfile_array=IO.readlines(skin_source[:name],'')
-          para_images=[]
-          skinfile_array.each do |f|                                           #% work area
-            unless f =~/^%+ / #hmmm
-              images << f.scan(@rgx_rb_image).uniq if f =~@rgx_rb_image
-              #does not really discriminate, may duplicate images in sisu file, and may take images from default image pool
+      and skin_source[:name_path]
+        unless skin_source[:name_path].nil? \
+        or skin_source[:name_path].empty?
+          if FileTest.file?(skin_source[:name_path])
+            FileUtils::cp(skin_source[:name_path],"#{docskin_place}/#{docskin}.rb")
+            skinfile_array=IO.readlines(skin_source[:name_path],'')
+            para_images=[]
+            skinfile_array.each do |f|                                           #% work area
+              unless f =~/^%+ / #hmmm
+                images << f.scan(@rgx_rb_image).uniq if f =~@rgx_rb_image
+                #does not really discriminate, may duplicate images in sisu file, and may take images from default image pool
+              end
             end
+          else STDERR.puts %{\t*WARN* did not find - "#{skin_source[:name_path]}" [#{__FILE__}:#{__LINE__}]}
           end
         end
       end
@@ -256,15 +258,21 @@ module SiSU_Doc
         if FileTest.directory?(images_pwd)
           images=images.uniq
           images.each do |i|
-            FileUtils::cp_r("#{images_pwd}/#{i}","#{images_path_pod}/#{i}") if FileTest.file?("#{images_pwd}/#{i}")
+            if FileTest.file?("#{images_pwd}/#{i}")
+              FileUtils::cp("#{images_pwd}/#{i}","#{images_path_pod}/#{i}") if FileTest.file?("#{images_pwd}/#{i}")
+            else STDERR.puts %{\t*WARN* did not find image - "#{images_pwd}/#{i}" [#{__FILE__}:#{__LINE__}]}
+            end
           end
-        else puts "\tWARN, did not find - #{images_pwd} #{images_path_pod}"
+        else STDERR.puts %{\t*WARN* did not find - #{images_pwd} #{images_path_pod} [#{__FILE__}:#{__LINE__}]}
         end
       end
       if doc_import.length > 0 \
       and @opt.fno =~/\.ssm$/
         doc_import.each do |f|
-          FileUtils::cp_r("#{@env.path.pwd}#{doc_import_dir}/#{f}","#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f}")
+          if FileTest.file?("#{@env.path.pwd}#{doc_import_dir}/#{f}")
+            FileUtils::cp("#{@env.path.pwd}#{doc_import_dir}/#{f}","#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f}")
+          else STDERR.puts %{\t*WARN* did not find image - "#{@env.path.pwd}#{doc_import_dir}/#{f}" [#{__FILE__}:#{__LINE__}]}
+          end
         end
       end
       x=@env.document_language_versions_found                                  #check multiple document language versions (param not used)
@@ -273,9 +281,38 @@ module SiSU_Doc
         x[:f].each do |f|
           pth="#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}"
           FileUtils::mkdir_p(pth) unless FileTest.directory?(pth)
-          (@opt.fno =~/\.ssm$/) \
-          ? FileUtils::cp_r("#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}","#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f[:n]}")
-          : FileUtils::cp_r("#{@env.path.pwd}/#{f[:f]}","#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f[:n]}")
+          if f[:f] =~/\~(\S{2,3})\.ss[tm]$/
+            lng_f=$1
+            if @opt.lng == lng_f
+              if @opt.fno =~/\.ssm$/
+                if FileTest.file?("#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}")
+                  FileUtils::cp("#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}",
+                    "#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f[:n]}")
+                else STDERR.puts %{\t*WARN* did not find - "#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}" [#{__FILE__}:#{__LINE__}]}
+                end
+              else
+                if FileTest.file?("#{@env.path.pwd}/#{f[:f]}")
+                  FileUtils::cp("#{@env.path.pwd}/#{f[:f]}",
+                    "#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f[:n]}")
+                else STDERR.puts %{\t*WARN* did not find - "#{@env.path.pwd}/#{f[:f]}" [#{__FILE__}:#{__LINE__}]}
+                end
+              end
+            end
+          else
+            if @opt.fno =~/\.ssm$/
+              if FileTest.file?("#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}")
+                FileUtils::cp_r("#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}",
+                  "#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f[:n]}")
+              else STDERR.puts %{\t*WARN* did not find - "#{@env.path.pwd}#{doc_import_dir}/#{f[:f]}" [#{__FILE__}:#{__LINE__}]}
+              end
+            else
+              if FileTest.file?("#{@env.path.pwd}/#{f[:f]}")
+                FileUtils::cp("#{@env.path.pwd}/#{f[:f]}",
+                  "#{@env.processing_path.processing_sisupod(@opt)}/doc/#{@opt.lng}/#{f[:n]}")
+              else STDERR.puts %{\t*WARN* did not find - "#{@env.path.pwd}/#{f[:f]}" [#{__FILE__}:#{__LINE__}]}
+              end
+            end
+          end
         end
       end #NB not all possibilies met, revisit, also in case of composite file may wish to add README
     end
@@ -303,7 +340,7 @@ module SiSU_Doc
   end
 end
 __END__
-question?:                   should you permit the packing of multiple files in single .gz ?
+question?:                   should you permit the packing of multiple documents in single .xz ?
 
   open @opt.fns, parse file
     extract from file content:
